@@ -1,8 +1,9 @@
-import textwrap
+import copy
 import os
 import re
 import sh
 import shutil
+import textwrap
 import yaml
 
 
@@ -157,9 +158,12 @@ class DotEnoughOpenStack(DotEnough):
                 c['auth']['username'] = v
             elif k == 'OS_PASSWORD' and v != '$OS_PASSWORD_INPUT':
                 c['auth']['password'] = v
+        clone = copy.deepcopy(c)
+        clone['region_name'] = 'DE1'
         open(clouds, 'w').write(yaml.dump({
             'clouds': {
-                'ovh': c
+                'production': c,
+                'clone': clone,
             }
         }))
         return c
