@@ -18,16 +18,21 @@ class Service(object):
         self.share_dir = share_dir
         self.ansible = ansible_utils.Ansible(
             self.config_dir, self.share_dir, kwargs.get('inventory', []))
-        self.set_service2hosts()
+        self.set_service_info()
         self.update_vpn_dependencies()
 
-    def set_service2hosts(self):
-        suffix = '-service-hosts'
+    def set_service_info(self):
         groups = self.ansible.get_groups()
+        suffix = '-service-hosts'
         self.service2hosts = {
             name.replace(suffix, ''): hosts for name, hosts in groups.items()
             if name.endswith(suffix)
         }
+        suffix = '-service-group'
+        self.service2group = {
+            name.replace(suffix, ''): hosts for name, hosts in groups.items()
+            if name.endswith(suffix)
+        }
 
     def update_vpn_dependencies(self):
         hosts = self.ansible.ansible_inventory()['_meta']['hostvars'].keys()
@@ -89,8 +94,8 @@ class ServiceOpenStack(Service):
         subdomain_regexp = r'(.*)\.d\.(.*)'
         m = re.match(subdomain_regexp, self.args['domain'])
         if not m:
-            log.info(f'{self.args["domain"]} does not match "{subdomain_regexp}", '
-                     'do not attempt to delegate the DNS')
+            log.debug(f'{self.args["domain"]} does not match "{subdomain_regexp}", '
+                      'do not attempt to delegate the DNS')
             return False
         (subdomain, domain) = m.group(1, 2)
         api = f'api.{domain}'
@@ -99,10 +104,10 @@ class ServiceOpenStack(Service):
         if not r.ok:
             raise ServiceOpenStack.PingException(f'{ping} does not respond')
 
-        h = openstack.Heat(self.config_dir, self.dotenough.clouds_file)
+        h = openstack.Heat(self.config_dir, cloud=self.args['cloud'])
         s = openstack.Stack(self.config_dir,
-                            self.dotenough.clouds_file,
-                            h.get_stack_definition('bind-host'))
+                            h.get_stack_definition('bind-host'),
+                            cloud=self.args['cloud'])
         s.set_public_key(self.dotenough.public_key())
         bind_host = s.create_or_update()
         r = requests.post(f'https://{api}/delegate-dns/',
@@ -115,7 +120,7 @@ class ServiceOpenStack(Service):
 
     def create_or_update(self):
         hosts = self.service2hosts[self.args['name']]
-        h = openstack.Heat(self.config_dir, self.dotenough.clouds_file)
+        h = openstack.Heat(self.config_dir, cloud=self.args['cloud'])
         h.create_missings(hosts, self.dotenough.public_key())
         self.maybe_delegate_dns()
         playbook = ansible_utils.Playbook(self.config_dir, self.share_dir)
@@ -123,6 +128,8 @@ class ServiceOpenStack(Service):
             playbook_file = self.args["playbook"]
         else:
             playbook_file = f'{self.config_dir}/{self.args["playbook"]}'
+            if not os.path.exists(playbook_file):
+                playbook_file = f'{self.share_dir}/{self.args["playbook"]}'
         playbook.run([
             f'--private-key={self.dotenough.private_key()}',
             '--limit', ','.join(hosts + ['localhost']),
