@@ -8,11 +8,16 @@ function prepare_environment() {
     if test $(id -u) != 0 ; then
         SUDO=sudo
     fi
-    $SUDO apt-get update
-    $SUDO apt-get install -y git
-    if test -d ~/.ansible ; then
+    if test "$(dpkg-query -W -f='${db:Status-Abbrev}' git)" != "ii " ; then
+        $SUDO apt-get update
+        $SUDO apt-get install -y git
+    fi
+    if test -d ~/.ansible && test "$(find ~/.ansible ! -user $(id -u) -print -quit)" ; then
         $SUDO chown -R $(id -u) ~/.ansible
     fi
+}
+
+function prepare_repository() {
     git submodule update --init --recursive
     chmod 600 infrastructure_key
 }
@@ -22,8 +27,8 @@ function prepare_inventory() {
         cat > tests/clouds.yml <<EOF
 ---
 clouds:
-  ovh:
-    auth:
+  production:
+    auth: &os_auth
       auth_url: "$OS_AUTH_URL"
       project_name: "$OS_PROJECT_NAME"
       project_id: "$OS_PROJECT_ID"
@@ -31,6 +36,10 @@ clouds:
       username: "$OS_USERNAME"
       password: "$OS_PASSWORD"
     region_name: "$OS_REGION_NAME"
+  clone:
+    auth:
+      <<: *os_auth
+    region_name: "DE1"
 EOF
         cp tests/clouds.yml inventory/group_vars/all/clouds.yml
     else
@@ -64,6 +73,9 @@ function build_image() {
     (
         cat enough/common/data/base.dockerfile
         cat tests/tox.dockerfile
+        if test "$GITLAB_CI" ; then
+            cat tests/copy-to-opt.dockerfile
+        fi
     ) | timeout $max_execution_time docker build --build-arg=USER_ID="$(id -u)" --build-arg=DOCKER_GID="$(getent group docker | cut -d: -f3)" --build-arg=USER_NAME="${USER:-root}" --tag $name -f - .
 }
 
@@ -78,23 +90,14 @@ function run_tests_on_ref() {
     mkdir -p $refdir
     if ! test -d $refdir/infrastructure ; then
         git clone --reference . . $refdir/infrastructure
-        cp -a bootstrap dev-links.sh $refdir/infrastructure
-        (
-            cd $refdir/infrastructure
-
-            bootstrap
-            ./dev-links.sh
-        )
     fi
 
     (
         cd $refdir/infrastructure
 
-        source ../virtualenv/bin/activate
-
         run_tests $name $refdir/infrastructure tox -e $service -- --enough-no-destroy playbooks/$service/tests
 
-        local c=.tox/$service/.pytest_cache
+        local c=.tox/$service/.pytest_cache/d
         mkdir -p $toplevel/$c
         rsync -av --delete $c/ $toplevel/$c/
     )
@@ -106,14 +109,14 @@ function run_tests() {
     local d="$1"
     shift
 
+    prepare_inventory
+    prepare_repository
+
     find $d \( -name '*.pyc' -o -name '*.pyo' -o -name __pycache__ \) -delete
     skip=""
     if test "$SKIP_OPENSTACK_INTEGRATION_TESTS" ; then
         skip+="-e SKIP_OPENSTACK_INTEGRATION_TESTS=true "
     fi
-    if test "$SKIP_NETWORK_OPENSTACK_INTEGRATION_TESTS" ; then
-        skip+="-e SKIP_NETWORK_OPENSTACK_INTEGRATION_TESTS=true "
-    fi
     if test "$GITLAB_CI" ; then
         args="--workdir /opt"
     else
@@ -125,6 +128,7 @@ function run_tests() {
 function main() {
     prepare_environment
     prepare_inventory
+
     local name=$(image_name "$@")
     echo -n Creating or refreshing the docker image to run the tests...
     build_image $name 15 < /dev/null > /dev/null 2>&1 || build_image $name 7200
